# pynewyear

[![PyPI version](https://badge.fury.io/py/pynewyear.svg)](https://pypi.org/project/pynewyear/1.0.0/)

Happy New Year! 🎄

## Installation:
```
pip install pynewyear
```

## Usage:
```
python -m pynewyear
```
